==> geant4.10.00.p04.tar.gz: geant4.10.00.p04/examples/extended/medical/DICOM/src/DicomActionInitialization.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// $Id: DicomActionInitialization.cc 68058 2013-07-22 14:47:43Z jmadsen $
//
/// \file DicomActionInitialization.cc
/// \brief Implementation of the DicomActionInitialization class


#include "DicomActionInitialization.hh"

#include "DicomActionInitialization.hh"
#include "DicomPrimaryGeneratorAction.hh"
#include "DicomRunAction.hh"
#include "DicomEventAction.hh"

//====================================================================================

DicomActionInitialization::DicomActionInitialization()
: G4VUserActionInitialization()
{  }

//====================================================================================

DicomActionInitialization::~DicomActionInitialization()
{  }

//====================================================================================

void DicomActionInitialization::BuildForMaster() const
{
    SetUserAction(new DicomRunAction);
}

//====================================================================================

void DicomActionInitialization::Build() const
{
    SetUserAction(new DicomPrimaryGeneratorAction);
    SetUserAction(new DicomRunAction);
    SetUserAction(new DicomEventAction);
    
}

//====================================================================================

==> geant4.10.01.p01.tar.gz: geant4.10.01.p01/examples/extended/medical/DICOM/src/DicomActionInitialization.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// $Id: DicomActionInitialization.cc 68058 2013-07-22 14:47:43Z jmadsen $
//
/// \file DicomActionInitialization.cc
/// \brief Implementation of the DicomActionInitialization class


#include "DicomActionInitialization.hh"

#include "DicomActionInitialization.hh"
#include "DicomPrimaryGeneratorAction.hh"
#include "DicomRunAction.hh"
#include "DicomEventAction.hh"

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

DicomActionInitialization::DicomActionInitialization()
: G4VUserActionInitialization()
{  }

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

DicomActionInitialization::~DicomActionInitialization()
{  }

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

void DicomActionInitialization::BuildForMaster() const
{
    SetUserAction(new DicomRunAction);
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

void DicomActionInitialization::Build() const
{
    SetUserAction(new DicomPrimaryGeneratorAction);
    SetUserAction(new DicomRunAction);
    SetUserAction(new DicomEventAction);
    
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
